@@ -19,12 +19,16 @@ struct TYPEMAKER2_TYPE {
 
   char *name;
 
+  char *descr;
+
   uint32_t flags;
   uint32_t setFlags;
   uint32_t getFlags;
   uint32_t dupFlags;
+  uint32_t copyFlags;
 
   int access;
+  int usePrivateConstructor;
 
   int type;
 
@@ -41,12 +45,17 @@ struct TYPEMAKER2_TYPE {
   char *aqdb_type;
   char *baseFileName;
 
+  char *freeHook;
+
+
   TYPEMAKER2_HEADER_LIST *headers;
   TYPEMAKER2_ENUM_LIST *enums;
   TYPEMAKER2_DEFINE_LIST *defines;
   TYPEMAKER2_CODE_LIST *codeDefs;
   TYPEMAKER2_INLINE_LIST *inlines;
   TYPEMAKER2_VIRTUALFN_LIST *virtualFns;
+  TYPEMAKER2_SIGNAL_LIST *signals;
+  TYPEMAKER2_SLOT_LIST *slots;
 
   GWEN_STRINGLIST *structIncludes;
   GWEN_STRINGLIST *privateIncludes;
